@@ -100,9 +100,9 @@ class DiscordPDA(discord.AutoShardedClient):
         """
         log.debug(f"Completing partial: {part!r}")
         if part.syntax:
-            command = part.complete(r"^\s+!{name}\s+{syntax}\s+$")
+            command = part.complete(r"^!{name}\s+{syntax}$")
         else:
-            command = part.complete(r"^\s+!{name}\s+$")
+            command = part.complete(r"^!{name}$")
         self.register_conversation(command)
         return command
 
